@@ -446,12 +446,26 @@ class ResourceManagerInterface(object):
 
         return rsc in self
 
-    def get_resources(self):
+    def get_resources(self, include_managers=True, allow_duplicates=False):
         """Return a list of registered resources.
 
         If multiple resources have the same alias the last one will be used.
+
+        Args:
+            include_managers (bool)[True]: If True include sub manager items.
+            allow_duplicates (bool)[True]: If True return all resources and do not check for duplicate aliases.
         """
-        return copy.copy(self)
+        rs = []
+        for rsc in reversed(self):
+            if allow_duplicates or rsc not in rs:
+                rs.append(rsc)
+
+        if include_managers and getattr(self, 'managers', None):
+            for man in reversed(self.managers):
+                rs.extend([rsc for rsc in man.get_resources(include_managers=True, allow_duplicates=allow_duplicates)
+                           if allow_duplicates or rsc not in rs])
+
+        return rs
 
     def get_resource(self, rsc, fallback=None, default=MISSING):
         """Return the found Resource object from the given resource, fallback, or default value.
